@@ -1,8 +1,8 @@
 #' Fit a (scalable) spatial Poisson mixed model to areal count data, where several CAR prior distributions can be specified for the spatial random effect.
 #'
-#' @description Fit a spatial Poisson mixed model to areal count data. The linear predictor is modelled as \deqn{\log{r_{i}}=\alpha+\mathbf{x_i}^{'}\beta + \xi_i, \quad \mbox{for} \quad i=1,\ldots,n;}
+#' @description Fit a spatial Poisson mixed model to areal count data. The linear predictor is modelled as \deqn{\log{r_{i}}=\alpha+\mathbf{x_i}^{'}\mathbf{\beta} + \xi_i, \quad \mbox{for} \quad i=1,\ldots,n;}
 #' where \eqn{\alpha} is a global intercept, \eqn{\mathbf{x_i}^{'}=(x_{i1},\ldots,x_{ip})} is a p-vector of standardized covariates in the i-th area,
-#' \eqn{\beta=(\beta_1,\ldots,\beta_p)} is the p-vector of fixed effects coefficients, and \eqn{\xi_i} is a spatially structured random effect.
+#' \eqn{\mathbf{\beta}=(\beta_1,\ldots,\beta_p)} is the p-vector of fixed effects coefficients, and \eqn{\xi_i} is a spatially structured random effect.
 #' Several conditional autoregressive (CAR) prior distributions can be specified for the spatial random effect, such as the intrinsic CAR prior \insertCite{besag1991}{bigDM}, the convolution or BYM prior \insertCite{besag1991}{bigDM},
 #' the CAR prior proposed by \insertCite{leroux1999estimation;textual}{bigDM}, and the reparameterization of the BYM model given by \insertCite{dean2001detecting;textual}{bigDM} named BYM2 \insertCite{riebler2016intuitive}{bigDM}.
 #'
@@ -41,17 +41,17 @@
 #'
 #' @param carto object of class \code{SpatialPolygonsDataFrame} or \code{sf}.
 #' This object must contain at least the target variables of interest specified in the arguments \code{ID.area}, \code{O} and \code{E}.
-#' @param ID.area character; name of the variable which contains the IDs of spatial areal units.
-#' @param ID.group character; name of the variable which contains the IDs of the spatial partition (grouping variable).
+#' @param ID.area character; name of the variable that contains the IDs of spatial areal units.
+#' @param ID.group character; name of the variable that contains the IDs of the spatial partition (grouping variable).
 #' Only required if \code{model="partition"}.
-#' @param O character; name of the variable which contains the observed number of disease cases for each areal units.
-#' @param E character; name of the variable which contains either the expected number of disease cases or the population at risk for each areal unit.
+#' @param O character; name of the variable that contains the observed number of disease cases for each areal units.
+#' @param E character; name of the variable that contains either the expected number of disease cases or the population at risk for each areal unit.
 #' @param X a character vector containing the names of the covariates within the \code{carto} object to be included in the model as fixed effects,
 #' or a matrix object playing the role of the fixed effects design matrix. For the latter case, the row names must match with the IDs of the spatial units defined by the \code{ID.area} variable.
 #' If \code{X=NULL} (default), only a global intercept is included in the model as fixed effect.
 #' @param confounding one of either \code{NULL}, \code{"restricted"} (restricted regression) or \code{"constraints"} (orthogonal constraints), which specifies the estimation method used to alleviate spatial confounding between fixed and random effects.
 #' If only an intercept is considered in the model (\code{X=NULL}), the default value \code{confounding=NULL} will be set.
-#' At the moment, only works for the \emph{Global model} (specified through the \code{model="global"} argument).
+#' At the moment, it only works for the \emph{Global model} (specified through the \code{model="global"} argument).
 #' @param W optional argument with the binary adjacency matrix of the spatial areal units.  If \code{NULL} (default), this object is computed from the \code{carto} argument (two areas are considered as neighbours if they share a common border).
 #' @param prior one of either \code{"Leroux"} (default), \code{"intrinsic"}, \code{"BYM"} or \code{"BYM2"},
 #' which specifies the prior distribution considered for the spatial random effect.
@@ -62,16 +62,16 @@
 #' @param strategy one of either \code{"gaussian"}, \code{"simplified.laplace"} (default), \code{"laplace"} or \code{"adaptive"},
 #' which specifies the approximation strategy considered in the \code{inla} function.
 #' @param PCpriors logical value (default \code{FALSE}); if \code{TRUE} then penalised complexity (PC) priors are used for the precision parameter of the spatial random effect.
-#' Only works if arguments \code{prior="intrinsic"} or \code{prior="BYM2"} are specified.
+#' It only works if arguments \code{prior="intrinsic"} or \code{prior="BYM2"} are specified.
 #' @param seed numeric (default \code{NULL}); control the RNG of the \code{inla.qsample} function. See \code{help(inla.qsample)} for further information.
 #' @param n.sample numeric; number of samples to generate from the posterior marginal distribution of the risks. Default to 1000.
-#' @param compute.fixed logical value (default \code{FALSE}); if \code{TRUE} then the overall log-risk \eqn{\alpha} is computed.
-#' Only works if \code{k=0} argument (\emph{Disjoint model}) is specified.
+#' @param compute.intercept logical value (default \code{FALSE}); if \code{TRUE} then the overall log-risk \eqn{\alpha} is computed.
+#' It only works if \code{k=0} argument (\emph{Disjoint model}) is specified. CAUTION: This method might be very time consuming.
 #' @param compute.DIC logical value; if \code{TRUE} (default) then approximate values of the Deviance Information Criterion (DIC) and Watanabe-Akaike Information Criterion (WAIC) are computed.
 #' @param merge.strategy one of either \code{"mixture"} or \code{"original"} (default), which specifies the merging strategy to compute posterior marginal estimates of relative risks. See \code{\link{mergeINLA}} for further details.
 #' @param save.models logical value (default \code{FALSE}); if \code{TRUE} then a list with all the \code{inla} submodels is saved in '/temp/' folder, which can be used as input argument for the \code{\link{mergeINLA}} function.
 #' @param plan one of either \code{"sequential"} or \code{"cluster"}, which specifies the computation strategy used for model fitting using the 'future' package.
-#' If \code{plan="sequential"} (default) the models are fitted sequentially and in the current R session (local machine). If \code{plan="cluster"} the models are fitted in parallel on external R sessions (local machine) or distributed in remote compute nodes.
+#' If \code{plan="sequential"} (default) the models are fitted sequentially and in the current R session (local machine). If \code{plan="cluster"} the models are fitted in parallel on external R sessions (local machine) or distributed in remote computing nodes.
 #' @param workers character or vector (default \code{NULL}) containing the identifications of the local or remote workers where the models are going to be processed. Only required if \code{plan="cluster"}.
 #'
 #' @return This function returns an object of class \code{inla}. See the \code{\link{mergeINLA}} function for details.
@@ -84,30 +84,37 @@
 #'
 #' @examples
 #' \dontrun{
+#' 
 #' if(require("INLA", quietly=TRUE)){
 #'
 #'   ## Load the Spain colorectal cancer mortality data ##
 #'   data(Carto_SpainMUN)
 #'
-#'   ## Fit the Global model with a Leroux CAR prior distribution ##
+#'   ## Global model with a Leroux CAR prior distribution ##
 #'   Global <- CAR_INLA(carto=Carto_SpainMUN, ID.area="ID", O="obs", E="exp",
 #'                      prior="Leroux", model="global", strategy="gaussian")
 #'
 #'   summary(Global)
 #'
-#'   ## Fit the Disjoint model with a Leroux CAR prior distribution ##
+#'   ## Disjoint model with a Leroux CAR prior distribution  ##
+#'   ## using 4 local clusters to fit the models in parallel ##
 #'   Disjoint <- CAR_INLA(carto=Carto_SpainMUN, ID.area="ID", ID.group="region", O="obs", E="exp",
-#'                        prior="Leroux", model="partition", k=0, strategy="gaussian")
+#'                        prior="Leroux", model="partition", k=0, strategy="gaussian",
+#'                        plan="cluster", workers=rep("localhost",4))
 #'   summary(Disjoint)
 #'
-#'   ## Fit the 1st order neighbourhood model with a Leroux CAR prior distribution ##
+#'   ## 1st-order neighbourhood model with a Leroux CAR prior distribution ##
+#'   ## using 4 local clusters to fit the models in parallel               ##
 #'   order1 <- CAR_INLA(carto=Carto_SpainMUN, ID.area="ID", ID.group="region", O="obs", E="exp",
-#'                      prior="Leroux", model="partition", k=1, strategy="gaussian")
+#'                      prior="Leroux", model="partition", k=1, strategy="gaussian",
+#'                      plan="cluster", workers=rep("localhost",4))
 #'   summary(order1)
 #'
-#'   ## Fit the 2nd order neighbourhood model with a Leroux CAR prior distribution ##
+#'   ## 2nd-order neighbourhood model with a Leroux CAR prior distribution ##
+#'   ## using 4 local clusters to fit the models in parallel               ##
 #'   order2 <- CAR_INLA(carto=Carto_SpainMUN, ID.area="ID", ID.group="region", O="obs", E="exp",
-#'                      prior="Leroux", model="partition", k=2, strategy="gaussian")
+#'                      prior="Leroux", model="partition", k=2, strategy="gaussian",
+#'                      plan="cluster", workers=rep("localhost",4))
 #'   summary(order2)
 #' }
 #' }
@@ -115,7 +122,7 @@
 #' @export
 CAR_INLA <- function(carto=NULL, ID.area=NULL, ID.group=NULL, O=NULL, E=NULL, X=NULL, confounding=NULL,
                      W=NULL, prior="Leroux", model="partition", k=0, strategy="simplified.laplace",
-                     PCpriors=FALSE, seed=NULL, n.sample=1000, compute.fixed=FALSE, compute.DIC=TRUE,
+                     PCpriors=FALSE, seed=NULL, n.sample=1000, compute.intercept=FALSE, compute.DIC=TRUE,
                      save.models=FALSE, plan="sequential", workers=NULL, merge.strategy="original"){
 
   if(suppressPackageStartupMessages(requireNamespace("INLA", quietly=TRUE))){
@@ -238,8 +245,10 @@ CAR_INLA <- function(carto=NULL, ID.area=NULL, ID.group=NULL, O=NULL, E=NULL, X=
 
                 cat(sprintf("+ Model %d of %d",d,D),"\n")
 
-                Rs <- inla.as.sparse(Rs)
-                Rs.Leroux <- inla.as.sparse(Rs.Leroux)
+                Rs <- as(Rs,"TsparseMatrix")
+                Rs.Leroux <- as(Rs.Leroux,"TsparseMatrix")
+                # Rs <- inla.as.sparse(Rs)
+                # Rs.Leroux <- inla.as.sparse(Rs.Leroux)
 
                 form <- "O ~ "
                 if(length(X)>0){
@@ -297,7 +306,7 @@ CAR_INLA <- function(carto=NULL, ID.area=NULL, ID.group=NULL, O=NULL, E=NULL, X=
                         if(confounding=="restricted"){
                                 cat("      + Alleviating spatial confounding: restricted regression model\n")
                                 p <- length(X)
-                                W <- Diagonal(n, Model$summary.fitted.values$mode*data.INLA$E)
+                                W <- Diagonal(n, Model$summary.fitted.values$`0.5quant`*data.INLA$E)
                                 W.sqrt <- Diagonal(n, sqrt(diag(W)))
 
                                 cat("         * Computing eigen decomposition... ")
@@ -335,7 +344,7 @@ CAR_INLA <- function(carto=NULL, ID.area=NULL, ID.group=NULL, O=NULL, E=NULL, X=
                         if(confounding=="constraints"){
                                 cat("      + Alleviating spatial confounding: orthogonality constraints model\n")
                                 p <- length(X)
-                                W <- Diagonal(n, Model$summary.fitted.values$mode*data.INLA$E)
+                                W <- Diagonal(n, Model$summary.fitted.values$`0.5quant`*data.INLA$E)
                                 Bs <- rbind(matrix(1,1,n)%*%W, t(as.matrix(data.INLA[,X]))%*%W)
                                 Bs <- as(Bs,"matrix")
 
@@ -420,7 +429,7 @@ CAR_INLA <- function(carto=NULL, ID.area=NULL, ID.group=NULL, O=NULL, E=NULL, X=
                 }
 
                 cat("STEP 3: Merging the results\n")
-                Model <- mergeINLA(inla.models=inla.models, k=k, seed=seed, n.sample=n.sample, compute.fixed=compute.fixed, compute.DIC=compute.DIC, merge.strategy=merge.strategy)
+                Model <- mergeINLA(inla.models=inla.models, k=k, seed=seed, n.sample=n.sample, compute.intercept=compute.intercept, compute.DIC=compute.DIC, merge.strategy=merge.strategy)
 
                 if(plan=="cluster"){
                         Model$cpu.used <- c(Running=as.numeric(cpu.time[3]), Merging=as.numeric(Model$cpu.used["Merging"]), Total=as.numeric(cpu.time[3]+Model$cpu.used["Merging"]))
